@@ -31,7 +31,10 @@ class TestEvent(object):
         d["notes"] = {}
 
         for key in self.Notes.keys():
-            d["notes"][key] = [str(e) for e in self.Notes[key]]
+            if type(d["notes"][key]) == list:
+                d["notes"][key] = [str(e) for e in self.Notes[key]]
+            else:
+                d["notes"][key] = str(e)
 
         s = dumps(d)
 
